import * as React from 'react';
import {connect} from 'react-redux';
import * as _ from 'underscore';
import {IReactVaporState} from '../../ReactVapor';
import {ReduxUtils} from '../../utils/ReduxUtils';
import {IReduxAction} from '../../utils/ReduxUtils';
import {IItemBoxProps} from '../itemBox/ItemBox';
import {IListBoxDispatchProps, IListBoxOwnProps, IListBoxProps, IListBoxStateProps, ListBox} from './ListBox';
import {addListBox, IListBoxPayload, removeListBox, selectListBoxOption} from './ListBoxActions';
import {IListBoxState} from './ListBoxReducers';

const mapStateToProps = (state: IReactVaporState, ownProps: IListBoxOwnProps): IListBoxStateProps => {
    const list: IListBoxState = _.findWhere(state.listBoxes, {id: ownProps.id});

    return {
        selected: list ? list.selected : [],
        active: list ? list.active : undefined,
    };
};

const mapDispatchToProps = (
    dispatch: (action: IReduxAction<IListBoxPayload>) => void,
    ownProps: IListBoxOwnProps,
): IListBoxDispatchProps => ({
    onRender: () => dispatch(addListBox(ownProps.id, ownProps.items)),
    onDestroy: () => dispatch(removeListBox(ownProps.id)),
    onOptionClick: (option: IItemBoxProps) => dispatch(selectListBoxOption(ownProps.id, ownProps.multi, option.value)),
});

export const ListBoxConnected: React.ComponentClass<IListBoxProps> =
    connect(mapStateToProps, mapDispatchToProps, ReduxUtils.mergeProps)(ListBox);
